@@ -17,6 +17,7 @@
 #include <tepl/tepl-application-window.h>
 #include <tepl/tepl-buffer.h>
 #include <tepl/tepl-file.h>
+#include <tepl/tepl-file-chooser.h>
 #include <tepl/tepl-file-loader.h>
 #include <tepl/tepl-file-saver.h>
 #include <tepl/tepl-fold-region.h>
@@ -31,6 +32,7 @@
 #include <tepl/tepl-metadata-manager.h>
 #include <tepl/tepl-notebook.h>
 #include <tepl/tepl-panel.h>
+#include <tepl/tepl-space-drawer-prefs.h>
 #include <tepl/tepl-statusbar.h>
 #include <tepl/tepl-style-scheme-chooser-widget.h>
 #include <tepl/tepl-tab.h>
